pytgressbar
=============

.. image:: https://img.shields.io/github/release/24aitor/pyprogressbar.svg
.. image:: https://img.shields.io/badge/Built%20For-Python%203.X-orange.svg
.. image:: https://img.shields.io/badge/license-MIT-blue.svg

What is pytgressbar?
---------------------

pytgressbar is a project to show a progress bar in python easily.

How to install?
---------------

pip install pytgressbar

Then in the file you want to use this package, you should import pytgressbar.

import pytgressbar


Screenshots of example.py output
--------------------------------

.. image:: https://imgur.com/FfJAA0g
